@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2012 Yoran Heling
+  Copyright (c) 2007-2014 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -24,11 +24,12 @@
 */
 
 #include "global.h"
-#include "khash.h"
 
 #include <string.h>
 #include <stdlib.h>
 
+#include <khash.h>
+
 
 static struct dir *root;   /* root directory struct we're scanning */
 static struct dir *curdir; /* directory item that we're currently adding items to */
@@ -84,8 +85,8 @@ static void hlink_check(struct dir *d) {
           if(pt==par)
             i=0;
     if(i) {
-      par->size += d->size;
-      par->asize += d->asize;
+      par->size = adds64(par->size, d->size);
+      par->asize = adds64(par->size, d->asize);
     }
   }
 }
@@ -197,7 +198,7 @@ static int final(int fail) {
     freedir(orig);
   }
 
-  browse_init(root->sub);
+  browse_init(root);
   dirlist_top(-3);
   return 0;
 }
