@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2012 Yoran Heling
+  Copyright (c) 2007-2014 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -196,6 +196,12 @@ static int dir_scan_item(struct dir *d) {
   if(!(d->flags & (FF_ERR|FF_EXL)))
     stat_to_dir(d, &st);
 
+  if(cachedir_tags && (d->flags & FF_DIR) && !(d->flags & (FF_ERR|FF_EXL|FF_OTHFS)))
+    if(has_cachedir_tag(d->name)) {
+      d->flags |= FF_EXL;
+      d->size = d->asize = 0;
+    }
+
   /* Recurse into the dir or output the item */
   if(d->flags & FF_DIR && !(d->flags & (FF_ERR|FF_EXL|FF_OTHFS)))
     fail = dir_scan_recurse(d);
@@ -260,12 +266,6 @@ static int process() {
   if(!dir_fatalerr && !(dir = dir_read(&fail)))
     dir_seterr("Error reading directory: %s", strerror(errno));
 
-  /* Special case: empty directory = error */
-  if(!dir_fatalerr && !*dir) {
-    dir_seterr("Directory empty");
-    free(dir);
-  }
-
   if(!dir_fatalerr) {
     curdev = (uint64_t)fs.st_dev;
     d = dir_createstruct(dir_curpath);
