@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2012 Yoran Heling
+  Copyright (c) 2007-2014 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -55,6 +55,7 @@
 #define ST_BROWSE 1
 #define ST_DEL    2
 #define ST_HELP   3
+#define ST_SHELL  4
 
 
 /* structure representing a file or directory */
@@ -102,5 +103,6 @@ int input_handle(int);
 #include "help.h"
 #include "path.h"
 #include "util.h"
+#include "shell.h"
 
 #endif
