@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2012 Yoran Heling
+  Copyright (c) 2007-2014 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -32,14 +32,14 @@
 
 #include <unistd.h>
 #include <sys/time.h>
-#include <locale.h>
 
-#include "yopt.h"
+#include <yopt.h>
 
 
 int pstate;
 int read_only = 0;
 long update_delay = 100;
+int cachedir_tags = 0;
 
 static int min_rows = 17, min_cols = 60;
 static int ncurses_init = 0;
@@ -52,6 +52,7 @@ static void screen_draw() {
     case ST_CALC:   dir_draw();    break;
     case ST_BROWSE: browse_draw(); break;
     case ST_HELP:   help_draw();   break;
+    case ST_SHELL:  shell_draw();  break;
     case ST_DEL:    delete_draw(); break;
   }
 }
@@ -125,10 +126,13 @@ static void argv_parse(int argc, char **argv) {
     { '2', 0, "-2" },
     {  1,  1, "--exclude" },
     { 'X', 1, "-X,--exclude-from" },
+    { 'C', 0, "--exclude-caches" },
+    { 's', 0, "--si" },
     {0,0,NULL}
   };
 
   dir_ui = -1;
+  si = 0;
 
   yopt_init(&yopt, argc, argv, opts);
   while((v = yopt_next(&yopt, &val)) != -1) {
@@ -144,8 +148,10 @@ static void argv_parse(int argc, char **argv) {
       printf("  -o FILE                    Export scanned directory to FILE\n");
       printf("  -f FILE                    Import scanned directory from FILE\n");
       printf("  -0,-1,-2                   UI to use when scanning (0=none,2=full ncurses)\n");
+      printf("  --si                       Use base 10 (SI) prefixes instead of base 2\n");
       printf("  --exclude PATTERN          Exclude files that match PATTERN\n");
       printf("  -X, --exclude-from FILE    Exclude files that match any pattern in FILE\n");
+      printf("  --exclude-caches           Exclude directories containing CACHEDIR.TAG\n");
       exit(0);
     case 'q': update_delay = 2000; break;
     case 'v':
@@ -153,6 +159,7 @@ static void argv_parse(int argc, char **argv) {
       exit(0);
     case 'x': dir_scan_smfs = 1; break;
     case 'r': read_only = 1; break;
+    case 's': si = 1; break;
     case 'o': export = val; break;
     case 'f': import = val; break;
     case '0': dir_ui = 0; break;
@@ -165,6 +172,9 @@ static void argv_parse(int argc, char **argv) {
         exit(1);
       }
       break;
+    case 'C':
+      cachedir_tags = 1;
+      break;
     case -2:
       printf("ncdu: %s.\n", val);
       exit(1);
@@ -245,7 +255,7 @@ static void init_nc() {
 
 /* main program */
 int main(int argc, char **argv) {
-  setlocale(LC_ALL, "");
+  read_locale();
   argv_parse(argc, argv);
 
   if(dir_ui == 2)
